// ==============================================================
//                 ORBITER MODULE: eaglecam
//                  
//
// eaglecam.cpp
// Control module for eaglecam vessel class
//
// 
// ==============================================================

#define STRICT
#define ORBITER_MODULE

#include "orbitersdk.h"
#include <cstdio>
#include <cmath>
#include <string>
#include <stdio.h>
#include <math.h>
#include "gcAPI.h"
#include "OrbiterSoundSDK40.h"
#include "eaglecam.h"


// ==============================================================
// Some vessel parameters
// ==============================================================

//const DWORD COMM_SEND_TGT = 2300;
//const DWORD COMM_SEND_RATE = 2301;

//const double ISP = 3200;
//const double RCSISP = 2275;
//const double RCSTH1 = 1.12;
//const double RCSTH2 = 27;
//const double MAINTH = 460;
//const double ARRAY_SPEED = 0.01;
//const double IPP_ALT_SPEED = 0.05;
//const double IPP_AZ_SPEED = 0.5;
//const double FUEL_MASS = 729;
const double EMP_MASS = 1;

#define YELLOW RGB(255, 255, 80)
#define GREEN RGB(0, 225, 0)

double stiffness = 1e3;
double damping = 2e2;
static TOUCHDOWNVTX tdvtx_geardown[3] = {
	{_V( 0,      -0.075,  0.2), stiffness, damping, 1.0, 0.2},
	{_V(-0.1732, -0.075, -0.1), stiffness, damping, 1.0, 0.2},
	{_V( 0.1732, -0.075, -0.1), stiffness, damping, 1.0, 0.2}
};




// Calculate lift coefficient [Cl] as a function of aoa (angle of attack) over -Pi ... Pi
// Implemented here as a piecewise linear function
//void VLiftCoeff (VESSEL *v, double aoa, double M, double Re, void *context, double *cl, double *cm, double *cd)
//{
//	int i;
//	const int nabsc = 9;
//	static const double AOA[nabsc] = {-180*RAD,-60*RAD,-30*RAD, -2*RAD, 10*RAD,15*RAD,50*RAD,90*RAD,180*RAD};
//	static const double CL[nabsc]  = {0,0,0,0,0,0,0,0,0};
//	static const double CM[nabsc]  = {0,0,0,0,0,0,0,0,0};
//	for (i = 0; i < nabsc-1 && AOA[i+1] < aoa; i++);
//	double f = (aoa-AOA[i]) / (AOA[i+1]-AOA[i]);
//	*cl = CL[i] + (CL[i+1]-CL[i]) * f;  // aoa-dependent lift coefficient
//	*cm = 0.0;
//	*cd = 0.95 + oapiGetInducedDrag (*cl, 1.5, 0.7) + oapiGetWaveDrag (M, 0.75, 1.0, 1.1, 0.04);
//}

//void HLiftCoeff (VESSEL *v, double aoa, double M, double Re, void *context, double *cl, double *cm, double *cd)
//{
//	int i;
//	const int nabsc = 9;
//	static const double AOA[nabsc] = {-180*RAD,-60*RAD,-30*RAD, -2*RAD, 10*RAD,15*RAD,50*RAD,90*RAD,180*RAD};
//	static const double CL[nabsc]  = {0,0,0,0,0,0,0,0,0};
//	static const double CM[nabsc]  = {0,0,0,0,0,0,0,0,0};
//	for (i = 0; i < nabsc-1 && AOA[i+1] < aoa; i++);
//	double f = (aoa-AOA[i]) / (AOA[i+1]-AOA[i]);
//	*cl = CL[i] + (CL[i+1]-CL[i]) * f;  // aoa-dependent lift coefficient
//	*cm = 0.0;
//	*cd = 0.95 + oapiGetInducedDrag (*cl, 1.5, 0.7) + oapiGetWaveDrag (M, 0.75, 1.0, 1.1, 0.04);
//}


class eaglecam: public VESSEL3 {
public:
	
	eaglecam (OBJHANDLE hVessel, int flightmodel);
	~eaglecam ();

	void clbkSetClassCaps (FILEHANDLE cfg);
	void clbkPreStep(double SimT, double SimDT, double MJD);
	void clbkPostStep (double simt, double simdt, double mjd);
	void clbkPostCreation();
	void clbkSaveState (FILEHANDLE scn);
	void clbkLoadStateEx (FILEHANDLE scn, void *status);
	bool clbkDrawHUD (int mode, const HUDPAINTSPEC *hps, oapi::Sketchpad *skp);
//	bool clbkLoadGenericCockpit ();
	int clbkConsumeBufferedKey(DWORD key, bool down, char *kstate);
	int clbkConsumeDirectKey(char *kstate);
	

private:
	void DoKillRot(void);
//	void SetCamPos();
	void DoPhoto();
//	void DoPrograde(void);
//	void DoRetrograde(void);
//	void DoOrbitNormal(void);
//	void DoOrbitAntiNormal(void);
//	void DoNadirPointing(void);

//	MGROUP_TRANSFORM *MgrpTran[47];
//	UINT anim_array, anim_ipp_alt, anim_ipp_az;
	int MyID;
//	THRUSTER_HANDLE th_main[1], th_rcs[14], th_group[6];
//	PROPELLANT_HANDLE hProp;
//	ANIMATIONCOMPONENT_HANDLE Section00, Section01, Section02, Section03, Section04, Section05;
//	ANIMATIONCOMPONENT_HANDLE Section06, Section07, Section08, Section09, Section10, Section11;
//	ANIMATIONCOMPONENT_HANDLE Section12, Section13, Section14, Section15, Section16, Section17;
//	ANIMATIONCOMPONENT_HANDLE Section18, Section19, Section20, Section21, Section22, Section23;
	ATTACHMENTHANDLE hAttach;
//	double array_proc, ipp_alt_proc, ipp_az_proc;
	int kilrot_sw, landed_sw; //array_status, ipp_alt_status, ipp_az_status, kilrot_sw, cam_status;
//	char tgtname[256];
	OBJHANDLE hParent;
//	VECTOR3 cam_dir_vector[3];
	int wndw_size;
	int photo_status, photo_px;
	SURFHANDLE surfTempPhoto;
	FILEHANDLE hFile;
	CAMERAHANDLE hCam;
	HDC hDCphoto;

	double photo_rate, photo_timer;
	bool gc_true, disable_imaging;
	int photo_count;
	VESSEL2* vNova;
	OBJHANDLE hNova;
	char caption[256];

};

eaglecam::eaglecam (OBJHANDLE hVessel, int flightmodel)
: VESSEL3 (hVessel, flightmodel)
{

}

eaglecam::~eaglecam ()
{

}





// ==============================================================
// eaglecam class interface
// ==============================================================

// ==============================================================
// Overloaded callback functions
// ==============================================================

// --------------------------------------------------------------
// Set the capabilities of the vessel class
// --------------------------------------------------------------
void eaglecam::clbkSetClassCaps (FILEHANDLE cfg)
{
	
//	cam_status = 0;
//	cam_dir_vector[0] = _V(0.043, 2.441, 3.391);
//	cam_dir_vector[1] = _V(0.043, 3.441, 3.391);
//	cam_dir_vector[2] = _V(0.043, 2.441, 2.391);
	wndw_size = 0;
	photo_status = -1;
	photo_px = 0;
	photo_rate = 2.0;
	photo_timer = 0.0;
	photo_count = 0;
	strcpy(caption, "EagleCam");

//	strcpy(tgtname, "NULL");
//	hTarget = NULL;

	gc_true = gcInitialize();
	disable_imaging = false;
	landed_sw = 0;
	kilrot_sw = 0;

	// physical specs
	SetCW (1, 1, 1, 1);
	SetRotDrag (_V(1,1,1));
	SetPMI (_V(0.1,0.1,0.1));
	SetCrossSections (_V(0.02,0.02,0.01));
	SetSize (0.2);
	SetEmptyMass (EMP_MASS);
	SetMeshVisibilityMode ((AddMesh ("nova_c/eaglecam")), MESHVIS_EXTERNAL);
	
	SetCameraOffset (_V(0,0,0));
	//SetTouchdownPoints (_V(0.1,0.8,-1.8), _V(0.512,-0.853,-1.8), _V(-0.512,-0.853,-1.8));
	SetTouchdownPoints ( tdvtx_geardown, 3);
	

	//////////////////// attach //////////////////////////

	hAttach = CreateAttachment (true, _V( 0, 0, 0), _V( 0,0,1), _V(0,1,0), "NOVA");

	oapiReadItem_bool (cfg, "DisableImaging", disable_imaging);

}

// ==============================================================
// API callback interface
// ==============================================================

// --------------------------------------------------------------
// Vessel initialisation
// --------------------------------------------------------------
DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
	return new eaglecam (hvessel, flightmodel);
}




// --------------------------------------------------------------
// Vessel cleanup
// --------------------------------------------------------------
DLLCLBK void ovcExit (VESSEL *vessel)
{
	if (vessel) delete (eaglecam*)vessel;
}
// ==============================================================
// Overloaded clbkPostCreation callback functions
// ==============================================================

void eaglecam::clbkPostCreation ()
{
	
	MyID=ConnectToOrbiterSoundDLL(GetHandle());
	//ReplaceStockSound(MyID,"Sound\\Vessel\\attsustain.wav",	REPLACE_MAIN_THRUST);
	SoundOptionOnOff(MyID,PLAYGPWS,FALSE);
	SoundOptionOnOff(MyID,PLAYCOUNTDOWNWHENTAKEOFF,FALSE);
	SoundOptionOnOff(MyID,PLAYLANDINGANDGROUNDSOUND,FALSE);
	SoundOptionOnOff(MyID,PLAYCABINAIRCONDITIONING,FALSE);
	SoundOptionOnOff(MyID,PLAYCABINRANDOMAMBIANCE,FALSE);
	SoundOptionOnOff(MyID,DISPLAYTIMER,FALSE);
	SoundOptionOnOff(MyID,PLAYDOCKLANDCLEARANCE,FALSE);
	SoundOptionOnOff(MyID,PLAYRADARBIP,FALSE);

	////////////////////////////////////

	hNova = GetAttachmentStatus(hAttach);
	if(hNova == NULL)
	{
	int ves_count = oapiGetVesselCount();
	int i;
	char ves_name[256];
	for (i = 0; i < ves_count; i++)
		{
			OBJHANDLE hTgt = oapiGetVesselByIndex(i);
			oapiGetObjectName(hTgt, ves_name, 4);
			if (!strnicmp (ves_name, "Nova", 4))hNova = hTgt;
		}
	}

	//////////////////////////////////

	////////////////// photo
	if(gc_true == true)
	{
	CreateDirectory(".\\Images\\EagleCam", NULL);
	hParent = GetAttachmentStatus(hAttach);
	if(hParent) photo_status = -1;
	}

	DWORD w, h;
	oapiGetViewportSize(&w, &h);
	wndw_size = h;
	
}
void eaglecam::clbkSaveState (FILEHANDLE scn)
{

	char cbuf[256];

	// default vessel parameters
	VESSEL3::clbkSaveState (scn);

	// custom parameters


	sprintf (cbuf, "%d", kilrot_sw);
	oapiWriteScenario_string (scn, "KROT", cbuf);

//	sprintf (cbuf, "%d", cam_status);
//	oapiWriteScenario_string (scn, "CAMR", cbuf);

	sprintf (cbuf, "%d %d %0.4f", photo_status, photo_count, photo_timer);
	oapiWriteScenario_string (scn, "IMAG", cbuf);

}
void eaglecam::clbkLoadStateEx (FILEHANDLE scn, void *vs)
{
    char *line;

	while (oapiReadScenario_nextline (scn, line)) {
		
		if (!strnicmp (line, "IMAG", 4))
		{
            sscanf (line+4, "%d%d%lf", &photo_status, &photo_count, &photo_timer);
		}
		else if (!strnicmp (line, "KROT", 4))
		{
            sscanf (line+4, "%d", &kilrot_sw);
		}
		else
		{
            ParseScenarioLineEx (line, vs);
			// unrecognised option - pass to Orbiter's generic parser
        }
   }
	
	
}






int eaglecam::clbkConsumeBufferedKey(DWORD key, bool down, char *kstate)
{


  if (!down) return 0; // only process keydown events

  if (KEYMOD_SHIFT (kstate)) // +shift
	{
	 /* switch (key) 
	  {
		
	  }*/
	  return 0;
	} 
  else if (KEYMOD_CONTROL (kstate)) // +ctrl
	{
	return 0;
	}
  else // unmodified keys
	{ 
    switch (key) 
		{
		//case OAPI_KEY_G: // solp
		//if (array_status  == 0)array_status = 1;
		//return 1;



		//case OAPI_KEY_P:
		//oapiOpenInputBox("Enter IPP Target Name",SetIPPTgt, 0, 50, 0);
		//return 1;



		case OAPI_KEY_B: // photo
		if (photo_status  == 0)photo_status = 2;
		else 
			{
			photo_status = 0;
			photo_timer = 0;
			}
		return 1;

		}
	return 0;
	}
  
 return 0;
 }


int eaglecam::clbkConsumeDirectKey(char *kstate)
{
		VECTOR3 avel = _V(0,0,0);
		GetAngularVel(avel);
		double dt = oapiGetSimStep();
		double drot = RAD*2*dt;

if (KEYMOD_SHIFT (kstate))
{
if (KEYDOWN (kstate, OAPI_KEY_NUMPAD2))
		{
		if (avel.x < RAD*10)
			{
			avel.x = avel.x+drot;
			if (avel.x > RAD*10) avel.x = RAD*10;
			}
		}

if (KEYDOWN (kstate, OAPI_KEY_NUMPAD8))
		{
		if (avel.x > -RAD*10)
			{
			avel.x = avel.x-drot;
			if (avel.x < -RAD*10) avel.x = -RAD*10;
			}
		}

if (KEYDOWN (kstate, OAPI_KEY_NUMPAD1))
		{
		if (avel.y < RAD*10)
			{
			avel.y = avel.y+drot;
			if (avel.y > RAD*10) avel.y = RAD*10;
			}
		}

if (KEYDOWN (kstate, OAPI_KEY_NUMPAD3))
		{
		if (avel.y > -RAD*10)
			{
			avel.y = avel.y-drot;
			if (avel.y < -RAD*10) avel.y = -RAD*10;
			}
		}

if (KEYDOWN (kstate, OAPI_KEY_NUMPAD6))
		{
		if (avel.z < RAD*10)
			{			
			avel.z = avel.z+drot;
			if (avel.z > RAD*10) avel.z = RAD*10;
			}
		}

if (KEYDOWN (kstate, OAPI_KEY_NUMPAD4))
		{
		if (avel.z > -RAD*10)
			{
			avel.z = avel.z-drot;
			if (avel.z < -RAD*10) avel.z = -RAD*10;
			}		
		}

		SetAngularVel(avel);
	}
else // unmodified keys
	{
	
	}
return 0;
}





bool eaglecam::clbkDrawHUD (int mode, const HUDPAINTSPEC *hps, oapi::Sketchpad *skp)
{

	// draw the default HUD
	VESSEL3::clbkDrawHUD (mode, hps, skp);

	int s = hps->H;
	double d = (s*0.00130208);
	int sw = ((hps->W));
	int lw =  (int)(16*sw/1024);
	int lwoffset = sw - (18*lw);
	int hlw = (int) (lw/2);


	int roxl = 0;
	int royl = 0;

	double ds = s;
	double dsw = sw;
	double sc_ratio = ds/dsw;


	if (sc_ratio < 0.7284)
	{
	roxl = (lw*10);
	royl = (int) (-88*d);
	}



	//int wd = (int)(152*d);
	int wc = (int)(168*d);
	int w0 = (int)(184*d);
	int w1 = (int) (200*d);
	int w2 = (int)(216*d);
	int w3 = (int)(232*d);
	//int w4 = (int)(248*d);
	//int w5 = (int)(264*d);
	//int w6 = (int)(280*d);
	//int w7 = (int)(296*d);
	//int w8 = (int)(312*d);
	//int w9 = (int)(328*d);
	//int w10 = (int)(344*d);
	//int w11 = (int)(360*d);
	//int w12 = (int)(376*d);
	//int w13 = (int)(392*d);
	//int w14 = (int)(408*d);
	//int w15 = (int)(424*d);



	{
	skp->SetTextColor(0x0066FF66);
	char abuf[256];
	sprintf(abuf,"Shift+NumPad = Reaction Wheel Attitude Control");
	skp->Text ((10+roxl), (w0+royl), abuf,strlen(abuf));
	}

	{
	skp->SetTextColor(0x0066FF66);
	if(kilrot_sw == 1)skp->SetTextColor(0x0066FFFF);
	char abuf[256];
	sprintf(abuf,"Shift+NumPad5 = Reaction Wheel KillRot");
	skp->Text ((10+roxl), (w1+royl), abuf,strlen(abuf));
	}


	


	{
	skp->SetTextColor(0x0066FF66);
	char abuf[256];
	sprintf(abuf,"B = Imaging: OFF");
	if(photo_status > 0)
		{
		skp->SetTextColor(0x0066FFFF);
		sprintf(abuf,"B = Imaging: ON");
		}
	skp->Text ((10+roxl), (w3+royl), abuf,strlen(abuf));
	}

	return true;
}


void eaglecam::clbkPreStep(double SimT, double SimDT, double MJD)
{
	if(GroundContact() == true && landed_sw == 0)landed_sw = 1;

	if (kilrot_sw  == 1)DoKillRot();

	hParent = GetAttachmentStatus(hAttach);
	if(hParent == NULL && photo_status == -1)
	{
		photo_status = 1;
		photo_timer = 1.5;
		//sprintf((oapiDebugString()), "photo_count %d photo_status %d", photo_count, photo_status);
	}
	//if(photo_status > 0 && GroundContact() == true)photo_status = 0;

	if(gc_true == false)photo_status = 0;
	if(disable_imaging == true)photo_status = 0;

	if(photo_status == 1)
	{
		photo_timer = photo_timer + SimDT;
		if(photo_timer > photo_rate)
		{
		photo_timer = 0;
		photo_status = 2;

		bool on_auto = true;
		if(photo_count > 6)on_auto = false;

		if(on_auto == true)
			{
			if(hNova == NULL)photo_status = 2;
			else
				{
				vNova = (VESSEL2*)oapiGetVesselInterface(hNova);
				double nova_alt = vNova->GetAltitude(ALTMODE_GROUND);
				if(nova_alt < 3)photo_status = 1;
				int fs = vNova->GetFlightStatus();
				//sprintf((oapiDebugString()), "fs %d", fs);
				if(fs == 1)photo_status = 2;
				}
			}
		}
	}
	else if(photo_status > 1)DoPhoto();
	
}


void eaglecam::clbkPostStep (double simt, double simdt, double mjd)
{
	if(GroundContact() == true && landed_sw == 0)landed_sw = 1;

	if(landed_sw == 1)
	{
	VESSELSTATUS2 vs;
	memset (&vs, 0, sizeof(vs));
	vs.version = 2;
	vs.rbody = GetGravityRef();
	vs.status = 1;
	OBJHANDLE hVessel = GetHandle();
	double heading;
	oapiGetHeading(hVessel,&heading);
	double lng, lat, rad;
	GetEquPos(lng, lat, rad);
	vs.surf_lat = lat;
	vs.surf_lng = lng;
	vs.surf_hdg = heading;
	vs.arot.x = 10;
	DefSetStateEx (&vs);
	landed_sw = 2;
	}
}

void eaglecam::DoKillRot()
{
		VECTOR3 avel = _V(0,0,0);
		GetAngularVel(avel);
		double dt = oapiGetSimStep();
		double drot = RAD*2*dt;

		if (drot > abs(avel.x)) avel.x = 0;
		else avel.x = avel.x + (drot * ((abs(avel.x))/-avel.x));
		if (drot > abs(avel.y)) avel.y = 0;
		else avel.y = avel.y + (drot * ((abs(avel.y))/-avel.y));
		if (drot > abs(avel.z)) avel.z = 0;
		else avel.z = avel.z + (drot * ((abs(avel.z))/-avel.z));

		SetAngularVel (avel);
		if (avel.x == 0 && avel.y == 0 && avel.z == 0) kilrot_sw = 0;
}

//bool eaglecam::clbkLoadGenericCockpit ()
//{
//	//SetCamPos();
//	return true;
//}

//void eaglecam::SetCamPos()
//{
//	
//	VECTOR3 camdir = _V(0,0,1);
//	double pfctr = 0;
//	
//	if (cam_status == 1)camdir = cam_dir_vector[1] - cam_dir_vector[0];
//	normalise(camdir);
//
//	pfctr = atan2(camdir.x, -camdir.z);
//	if(pfctr > PI)pfctr = pfctr - PI2;
//	SetCameraDefaultDirection (camdir,pfctr);
//	oapiCameraAttach(GetHandle(), 2);
//	
//	oapiCameraSetCockpitDir(0, 0);
//
//}

void eaglecam::DoPhoto()
{
DWORD dwFlags = 0xFF;

if(photo_status == 2)
	{
	
	surfTempPhoto = oapiCreateSurface(wndw_size, wndw_size);
	gcConvertSurface(surfTempPhoto,OAPISURFACE_RENDER3D);

	VECTOR3 campos = _V(0,0.5,0.1);
	VECTOR3 camdir = _V(0,0.5,0.866);
	VECTOR3 camup =  _V(0,0.866,-0.5);
	hCam = gcSetupCustomCamera(NULL, GetHandle(), campos, camdir, camup, (60*RAD), surfTempPhoto, dwFlags);
	gcCustomCameraOnOff(hCam, true);

	photo_status = 3;
	}
else if(photo_status > 2 && photo_status < 6)
{

	if(photo_status == 5)
	{
	VECTOR3 campos = _V(0,0.5,0.1);
	VECTOR3 camdir = _V(0,0.5,0.866);
	VECTOR3 camup =  _V(0,0.866,-0.5);
	gcSetupCustomCamera(hCam, GetHandle(), campos, camdir, camup, (60*RAD), surfTempPhoto, dwFlags);
	}
	photo_status = photo_status + 1;
}
else if(photo_status == 6)
	{
	photo_count = photo_count + 1;

	int W = wndw_size;
	int H = wndw_size;
	photo_px = (int) (wndw_size*0.50);
	if(photo_px < 150)photo_px = 150;
	if(photo_px > wndw_size)photo_px = (int)(wndw_size/2);

	///////////////////////////
		oapi::Font *font = oapiCreateFont (14, true, "Sans", FONT_NORMAL);
		oapi::Sketchpad *skp = oapiGetSketchpad (surfTempPhoto);
		if (skp) {
		skp->SetFont (font);
		skp->SetTextColor (0x00FFFFFF);
		skp->SetTextAlign (oapi::Sketchpad::CENTER);
		//char cbuf[32];
		//strncpy (cbuf, GetName(), 10);
		//sprintf((oapiDebugString()), cbuf);
		//if(dim_range > 1000000)sprintf(cbuf, "Dimorphos %0.3f Gm", dim_range*0.000001);
		//else if(dim_range > 1000)sprintf(cbuf, "Dimorphos %0.3f Mm", dim_range*0.001);
		//else if(dim_range > 0)sprintf(cbuf, "Dimorphos %0.3f km", dim_range);
		//else sprintf(cbuf, "Dimorphos %0.3f m", dim_range*1000);
		//strcat(cbuf, abuf);//
		//int len = min(strlen(GetName()), 10);
		int y_off = (int)(photo_px/2 - 15);
		int len = strlen(caption);
		skp->Text ((int)(W/2), y_off+((int)(H/2)), caption, len);
		oapiReleaseSketchpad (skp);
		}
		oapiReleaseFont (font);
		////////////////////////////

	SURFHANDLE temp  = oapiCreateSurface (photo_px, photo_px);
	//sprintf((oapiDebugString()), "W %d photo_px %d", W, photo_px);
	// copy the cropped portion of the screenshot to a photo surface
		hDCphoto = oapiGetDC (surfTempPhoto);
		HDC hDCtemp = oapiGetDC (temp); 
		BitBlt(hDCtemp, 0, 0, photo_px, photo_px, hDCphoto, (int)((W-photo_px)/2),(int)((H-photo_px)/2), SRCCOPY); 
		
		HDC dcSave = CreateCompatibleDC(hDCtemp);
			HBITMAP bmpSave = CreateCompatibleBitmap(hDCtemp, photo_px, photo_px);
			SelectObject(dcSave, bmpSave);
			BitBlt(dcSave, 0, 0, photo_px, photo_px, hDCtemp, 0, 0, SRCCOPY);

			char filename[256];
            sprintf(filename, "Images\\EagleCam\\%0.5f.bmp", oapiGetSimMJD());

			SaveBitmapFile(dcSave, bmpSave, filename);
		
		
		oapiReleaseDC (temp, hDCtemp);
		oapiDestroySurface (temp);
		photo_status = 1;
		if(photo_count == 6)
		{
			photo_status = 0;
			photo_timer = 0;
			
		}
		gcCustomCameraOnOff(hCam, false);
		gcDeleteCustomCamera(hCam);
		oapiReleaseDC (surfTempPhoto, hDCphoto); 
		DeleteObject(bmpSave);
		DeleteObject(surfTempPhoto);
	}
}



//void eaglecam::DoNadirPointing()
//{
//	VESSELSTATUS vs;
//	GetStatus(vs);
//
//	//OBJHANDLE hGbod = GetGravityRef();
//	OBJHANDLE hGbod = oapiGetObjectByName("Moon");
//
//	VECTOR3 pos_unit = _V(0,0,0);
//	GetRelativePos(hGbod, pos_unit);
//	normalise(pos_unit);
//
//	VECTOR3 vel_unit = vs.rvel;
//	normalise(vel_unit);
//
//	VECTOR3 my_pos_glob_unit = _V(0,0,0);
//	GetGlobalPos(my_pos_glob_unit);
//	normalise(my_pos_glob_unit);
//
//	//VECTOR3 vel_pos_nml = crossp(vel_unit, pos_unit);
//	//normalise(vel_pos_nml);
//
//	VECTOR3 x_unit = crossp(pos_unit, my_pos_glob_unit);
//	normalise(x_unit);
//
//	VECTOR3 y_unit = pos_unit;
//	normalise(y_unit);
//
//	VECTOR3 z_unit = crossp(x_unit,y_unit);
//	normalise(z_unit);
//
//	//sprintf(oapiDebugString(), "x %0.3f y %0.3f z %0.3f tot %0.3f",x_unit.x, x_unit.y, x_unit.z, length(x_unit));
//
//
//	VECTOR3 xright = x_unit;
//	VECTOR3 yup = y_unit;
//	VECTOR3 zforward = z_unit;
//
//
//double gamma = atan2( xright.x, yup.x);
//double beta = -1*(asin(zforward.x));
//double alpha = atan2(zforward.y, zforward.z);
//
//vs.arot = _V(alpha, beta, (PI/2)-gamma);
//vs.vrot = _V(0,0,0);
//
//DefSetState(&vs);
//
//}